OC.L10N.register(
    "text",
    {
    "Translate" : "Орчуулга",
    "Guest" : "Зочин",
    "Saved" : "Хадгалах",
    "Cancel" : "Цуцлах",
    "URL" : "URL",
    "to" : "Дуусах нь",
    "Replace" : "Солих",
    "Source code" : "эх үүсвэр талын код",
    "Undo" : "буцах",
    "Info" : "Info",
    "Warning" : "Warning",
    "Edit" : "засварлах",
    "Unsupported image type" : "Дэмжигдэхгүй зургийн төрөл байна"
},
"nplurals=2; plural=(n != 1);");
